@@ -108,6 +108,7 @@ this.filterAtomTypeStr = null;
 this.filterAtomNameTerminator = ";";
 this.filterElement = false;
 this.filterHetero = false;
+this.filterAllHetero = false;
 this.filterEveryNth = false;
 this.filterSymop = null;
 this.filterN = 0;
@@ -655,9 +656,11 @@ if (this.filter == null) return;
 if (this.checkFilterKey ("HETATM")) {
 this.filterHetero = true;
 this.filter = JU.PT.rep (this.filter, "HETATM", "HETATM-Y");
+this.filterCased = JU.PT.rep (this.filterCased, "HETATM", "HETATM-Y");
 }if (this.checkFilterKey ("ATOM")) {
 this.filterHetero = true;
 this.filter = JU.PT.rep (this.filter, "ATOM", "HETATM-N");
+this.filterCased = JU.PT.rep (this.filterCased, "ATOM", "HETATM-N");
 }if (this.checkFilterKey ("CELL=")) this.strSupercell = this.filter.substring (this.filter.indexOf ("CELL=") + 5).toLowerCase ();
 this.nameRequired = JU.PT.getQuotedAttribute (this.filter, "NAME");
 if (this.nameRequired != null) {
@@ -671,6 +674,7 @@ this.filterGroup3 = this.checkFilterKey ("[");
 this.filterChain = this.checkFilterKey (":");
 this.filterAltLoc = this.checkFilterKey ("%");
 this.filterEveryNth = this.checkFilterKey ("/=");
+this.filterAllHetero = this.checkFilterKey ("ALLHET");
 if (this.filterEveryNth) this.filterN = this.parseIntAt (this.filter, this.filter.indexOf ("/=") + 2);
  else if (this.filter.startsWith ("=") || this.filter.indexOf (";=") >= 0) this.filterAtomType = this.checkFilterKey ("=");
 if (this.filterN == -2147483648) this.filterEveryNth = false;
@@ -720,12 +724,13 @@ function (atom, iAtom) {
 if (!this.haveAtomFilter) return true;
 var isOK = this.checkFilter (atom, this.filter1, this.filter1Cased);
 if (this.filter2 != null) isOK = new Boolean (isOK | this.checkFilter (atom, this.filter2, this.filter2Cased)).valueOf ();
-if (isOK && this.filterEveryNth) isOK = (((this.nFiltered++) % this.filterN) == 0);
+if (isOK && this.filterEveryNth && (!atom.isHetero || !this.filterAllHetero)) isOK = (((this.nFiltered++) % this.filterN) == 0);
 this.bsFilter.setBitTo (iAtom >= 0 ? iAtom : this.asc.ac, isOK);
 return isOK;
 }, "J.adapter.smarter.Atom,~N");
 Clazz.defineMethod (c$, "checkFilter", 
  function (atom, f, fCased) {
+if (atom.isHetero && this.filterAllHetero) return true;
 return (!this.filterGroup3 || atom.group3 == null || !this.filterReject (f, "[", atom.group3.toUpperCase () + "]")) && (!this.filterAtomName || this.allowAtomName (atom.atomName, f)) && (this.filterAtomTypeStr == null || atom.atomName == null || atom.atomName.toUpperCase ().indexOf ("\0" + this.filterAtomTypeStr) >= 0) && (!this.filterElement || atom.elementSymbol == null || !this.filterReject (f, "_", atom.elementSymbol.toUpperCase () + ";")) && (!this.filterChain || atom.chainID == 0 || !this.filterReject (fCased, ":", "" + this.vwr.getChainIDStr (atom.chainID))) && (!this.filterAltLoc || atom.altLoc == '\0' || !this.filterReject (f, "%", "" + atom.altLoc)) && (!this.filterHetero || !this.allowPDBFilter || !this.filterReject (f, "HETATM", atom.isHetero ? "-Y" : "-N"));
 }, "J.adapter.smarter.Atom,~S,~S");
 Clazz.defineMethod (c$, "rejectAtomName", 
