@@ -209,9 +209,9 @@ function (asc) {
 return (asc).atomSetInfo;
 }, "~O");
 Clazz.overrideMethod (c$, "getAtomSetCount", 
-function (asc) {
-return (asc).atomSetCount;
-}, "~O");
+function (asc, modelIndex) {
+return (modelIndex < 0 ? (asc).atomSetCount : (asc).getAtomSetAtomCount (modelIndex));
+}, "~O,~N");
 Clazz.overrideMethod (c$, "getAtomSetNumber", 
 function (asc, atomSetIndex) {
 return (asc).getAtomSetNumber (atomSetIndex);
