@@ -134,10 +134,11 @@ Clazz.overrideMethod (c$, "appUpdateSpecialCheckBoxValue",
 function (source, actionCommand, selected) {
 if (source == null || !selected) return;
 var name = source.getName ();
-if (!this.updatingForShow && this.setActiveMenu (name) != null) {
+var mode;
+if (!this.updatingForShow && (mode = this.setActiveMenu (name)) != null) {
 this.exitBondRotation ();
 var text = source.getText ();
-if (this.activeMenu === "bondMenu") {
+if (mode === "bondMenu") {
 if (name.equals (this.bondRotationName)) {
 this.bondRotationCheckBox = source;
 } else {
@@ -147,6 +148,7 @@ this.prevBondCheckBox = source;
 Clazz.defineMethod (c$, "exitBondRotation", 
 function () {
 this.modelkit.exitBondRotation (this.prevBondCheckBox == null ? null : this.prevBondCheckBox.getText ());
+this.vwr.setPickingMode (null, 33);
 if (this.bondRotationCheckBox != null) this.bondRotationCheckBox.setSelected (false);
 if (this.prevBondCheckBox != null) this.prevBondCheckBox.setSelected (true);
 });
@@ -181,7 +183,6 @@ for (var item, $item = this.htCheckbox.values ().iterator (); $item.hasNext () &
 if (item.getActionCommand ().indexOf (":??") < 0) continue;
 this.menuSetLabel (item, "??");
 item.setActionCommand ("_??P!:");
-item.setSelected (false);
 }
 this.appRunScript ("set picking assignAtom_C");
 return;
@@ -205,8 +206,8 @@ function (menuName) {
 var thisBondType = "assignBond_" + this.modelkit.pickBondAssignType;
 var thisAtomType = "assignAtom_" + this.modelkit.pickAtomAssignType + "P";
 for (var entry, $entry = this.htCheckbox.entrySet ().iterator (); $entry.hasNext () && ((entry = $entry.next ()) || true);) {
-var key = entry.getKey ();
 var item = entry.getValue ();
+var key = item.getActionCommand ();
 if (key.startsWith (thisBondType) || key.startsWith (thisAtomType)) {
 this.updatingForShow = true;
 item.setSelected (false);
