@@ -80,8 +80,8 @@ this.thisx = -this.thisx - 50;
 if (this.nFrankList > 1) {
 this.thisy -= this.nFrankList * 20;
 this.menuShowPopup (this.frankPopup, this.thisx, this.thisy);
-return false;
-}return true;
+return true;
+}return false;
 });
 Clazz.overrideMethod (c$, "jpiUpdateComputedMenus", 
 function () {
