@@ -79,7 +79,8 @@ this.stepBohr[i] = stepsXYZ[i] * this.unitFactor;
 this.volume *= this.stepBohr[i];
 }
 JU.Logger.info ("QuantumCalculation:\n origin = " + JU.Escape.eAF (originXYZ) + "\n steps = " + JU.Escape.eAF (stepsXYZ) + "\n origin(Bohr)= " + JU.Escape.eAF (this.originBohr) + "\n steps(Bohr)= " + JU.Escape.eAF (this.stepBohr) + "\n counts= " + this.nX + " " + this.nY + " " + this.nZ);
-}this.qmAtoms =  new Array (renumber ? bsSelected.cardinality () : xyz.length);
+}if (atoms == null) return;
+this.qmAtoms =  new Array (renumber ? bsSelected.cardinality () : xyz.length);
 var isAll = (bsSelected == null);
 var i0 = (isAll ? this.qmAtoms.length - 1 : bsSelected.nextSetBit (0));
 for (var i = i0, j = 0; i >= 0; i = (isAll ? i - 1 : bsSelected.nextSetBit (i + 1))) this.qmAtoms[renumber ? j++ : i] =  new J.quantum.QMAtom (i, xyz[i], atoms[i], this.X, this.Y, this.Z, this.X2, this.Y2, this.Z2, this.unitFactor);
