@@ -156,10 +156,10 @@ function () {
 return this.ms.ac;
 });
 Clazz.defineMethod (c$, "createModelSet", 
- function (adapter, asc, bsNew) {
+ function (adapter, asc, bs2D) {
 var nAtoms = (adapter == null ? 0 : adapter.getAtomCount (asc));
 if (nAtoms > 0) JU.Logger.info ("reading " + nAtoms + " atoms");
-this.adapterModelCount = (adapter == null ? 1 : adapter.getAtomSetCount (asc));
+this.adapterModelCount = (adapter == null ? 1 : adapter.getAtomSetCount (asc, -1));
 this.appendToModelIndex = (this.ms.msInfo == null ? null : (this.ms.msInfo.get ("appendToModelIndex")));
 this.appendNew = !this.isMutate && (!this.merging || adapter == null || this.adapterModelCount > 1 || this.isTrajectory || this.vwr.getBoolean (603979792) && this.appendToModelIndex == null);
 this.htAtomMap.clear ();
@@ -175,8 +175,8 @@ this.iModel = -1;
 this.model = null;
 if (this.merging) this.mergeTrajAndVib (this.modelSet0, this.ms);
 this.initializeAtomBondModelCounts (nAtoms);
-if (bsNew != null && (this.doMinimize || this.is2D)) {
-bsNew.setBits (this.baseAtomIndex, this.baseAtomIndex + nAtoms);
+if (bs2D != null && (this.doMinimize || this.is2D)) {
+bs2D.setBits (this.baseAtomIndex, this.baseAtomIndex + nAtoms);
 }if (adapter == null) {
 this.setModelNameNumberProperties (0, -1, "", 1, null, null, null);
 } else {
@@ -858,7 +858,8 @@ this.ms.elementsPresent[a.mi].set (n);
 });
 Clazz.defineMethod (c$, "applyStereochemistry", 
  function () {
-this.set2DLengths (this.baseAtomIndex, this.ms.ac);
+var atomCount = this.ms.ac;
+this.set2DLengths (this.baseAtomIndex, atomCount);
 var v =  new JU.V3 ();
 if (this.vStereo != null) {
 out : for (var i = this.vStereo.size (); --i >= 0; ) {
@@ -875,10 +876,10 @@ if ((b.order == 1025) == (v.y < 0)) this.stereodir = -1;
 break out;
 }}
 }
-}this.set2dZ (this.baseAtomIndex, this.ms.ac, v);
+}this.set2dZ (this.baseAtomIndex, atomCount, v);
 if (this.vStereo != null) {
 var bsToTest =  new JU.BS ();
-bsToTest.setBits (this.baseAtomIndex, this.ms.ac);
+bsToTest.setBits (this.baseAtomIndex, atomCount);
 for (var i = this.vStereo.size (); --i >= 0; ) {
 var b = this.vStereo.get (i);
 var dz2 = (b.order == 1025 ? 3 : -3);
