@@ -179,7 +179,7 @@ return this.atom2.index;
 });
 Clazz.overrideMethod (c$, "getCovalentOrder", 
 function () {
-return this.order & -131073;
+return this.order & 131071;
 });
 Clazz.overrideMethod (c$, "getOtherNode", 
 function (atom) {
@@ -198,7 +198,7 @@ function () {
 var a = this.atom1;
 this.atom1 = this.atom2;
 this.atom2 = a;
-switch (this.order & -131073) {
+switch (this.order & 131071) {
 case 65537:
 this.order = 65538;
 break;
@@ -215,14 +215,14 @@ break;
 });
 Clazz.defineMethod (c$, "getRealCovalentOrder", 
 function () {
-switch (this.order & -131073) {
+switch (this.order & 131071) {
 case 65537:
 case 65538:
 case 1025:
 case 1041:
 return 1;
 }
-return this.order & -131073;
+return this.order & 131071;
 });
 Clazz.defineMethod (c$, "getMatchingBond", 
 function () {
