@@ -1009,7 +1009,7 @@ if (isBio) {
 data = sgName;
 } else {
 if (haveName && !haveRawName) sym.setSpaceGroupName (sgName);
-data = sym.getSpaceGroupInfoObj (sgName, cellInfo, isFull, !isForModel);
+data = sym.getSpaceGroupInfoObj (sgName, (cellInfo == null ? null : cellInfo.getUnitCellParams ()), isFull, !isForModel);
 if (data == null || data.equals ("?")) {
 data = "?";
 info.put ("spaceGroupNote", "could not identify space group from name: " + sgName + "\nformat: show spacegroup \"2\" or \"P 2c\" " + "or \"C m m m\" or \"x, y, z;-x ,-y, -z\"");
