@@ -1,5 +1,5 @@
 Clazz.declarePackage ("JSV.source");
-Clazz.load (null, "JSV.source.BrukerReader", ["java.io.BufferedInputStream", "$.ByteArrayInputStream", "$.File", "$.FileInputStream", "java.lang.Double", "java.util.Hashtable", "java.util.zip.ZipInputStream", "JU.BinaryDocument", "$.Lst", "JSV.common.Coordinate", "$.Spectrum", "JSV.source.JDXReader", "$.JDXSource"], function () {
+Clazz.load (null, "JSV.source.BrukerReader", ["java.io.BufferedInputStream", "$.ByteArrayInputStream", "$.File", "$.FileInputStream", "java.lang.Double", "java.util.Hashtable", "java.util.zip.ZipInputStream", "JU.BinaryDocument", "$.Lst", "$.Rdr", "JSV.common.Coordinate", "$.Spectrum", "JSV.source.JDXReader", "$.JDXSource"], function () {
 c$ = Clazz.decorateAsClass (function () {
 this.allowPhasing = false;
 Clazz.instantialize (this, arguments);
@@ -20,6 +20,7 @@ var root = null;
 var title = null;
 out : while ((ze = zis.getNextEntry ()) != null) {
 var zeName = ze.getName ();
+System.out.println (zeName);
 var pt = zeName.lastIndexOf ('/');
 var zeShortName = zeName.substring (pt + 1);
 if (root == null) {
@@ -234,17 +235,8 @@ return this.getBytes ( new java.io.FileInputStream (file), len, true);
 }, "java.io.File");
 Clazz.defineMethod (c$, "getBytes", 
  function ($in, len, andClose) {
-var bytes =  Clazz.newByteArray (len, 0);
 try {
-var pos = 0;
-while (len > 0) {
-var n = $in.read (bytes, pos, len);
-if (n < 0) break;
-len -= n;
-pos += n;
-}
-if (andClose) $in.close ();
-return bytes;
+return JU.Rdr.getLimitedStreamBytes ($in, len);
 } catch (e) {
 if (Clazz.exceptionOf (e, Exception)) {
 } else {
