@@ -210,7 +210,7 @@ pixels = objImage;
 } else {
 {
 pixels = null;
-}pixels = this.vwr.apiPlatform.grabPixels (objImage, width, height, pixels, 0, height);
+}pixels = this.vwr.apiPlatform.grabPixels (objImage, width, height, pixels);
 }return pixels;
 }, "~N,~N,~O");
 Clazz.defineMethod (c$, "outputToFile", 
