@@ -1,4 +1,4 @@
-(function(ma,na,oa,pa,V,qa,Y,y,Z,ia,ja,$,ra,ka,sa,L,O,ta,C,la,ua,va,wa,xa,ya,za,Aa,Ba,Ca,Da,x,Ea,Fa,Ga,Ha,Ia,Ja,Ka,La,Ma,Na,Oa,Pa,Qa,Ra,Sa,Ta,Ua,Va,Wa,Xa,Ya,Za,$a,ab,bb,cb,db,m){Y("JS");Z(["java.lang.Float"],"JS.MathExt","java.lang.Number java.util.Date $.HashMap $.Hashtable $.Random JU.AU $.BS $.CU $.Lst $.M3 $.M4 $.Measure $.OC $.P3 $.P4 $.PT $.Quat $.Rdr $.SB $.V3 J.api.Interface J.atomdata.RadiusData J.bspt.PointIterator J.c.VDW J.i18n.GT JM.BondSet $.Measurement JS.SV $.ScriptParam $.T JU.BSUtil $.BoxInfo $.Escape $.JmolMolecule $.Logger $.Parser $.Point3fi $.SimpleUnitCell JV.FileManager $.JC $.Viewer".split(" "),
+(function(ma,na,oa,pa,V,qa,Y,y,Z,ia,ja,$,ra,ka,sa,L,O,ta,C,la,ua,va,wa,xa,ya,za,Aa,Ba,Ca,Da,x,Ea,Fa,Ga,Ha,Ia,Ja,Ka,La,Ma,Na,Oa,Pa,Qa,Ra,Sa,Ta,Ua,Va,Wa,Xa,Ya,Za,$a,ab,bb,cb,db,m){Y("JS");Z(["java.lang.Float"],"JS.MathExt","java.lang.Number java.util.Date $.HashMap $.Hashtable $.Random JU.AU $.BArray $.BS $.CU $.Lst $.M3 $.M4 $.Measure $.OC $.P3 $.P4 $.PT $.Quat $.Rdr $.SB $.V3 J.api.Interface J.atomdata.RadiusData J.bspt.PointIterator J.c.VDW J.i18n.GT JM.BondSet $.Measurement JS.SV $.ScriptParam $.T JU.BSUtil $.BoxInfo $.Escape $.JmolMolecule $.Logger $.Parser $.Point3fi $.SimpleUnitCell JV.FileManager $.JC $.Viewer".split(" "),
 function(){c$=ja(function(){this.pm=this.rand=this.e=this.vwr=null;ia(this,arguments)},JS,"MathExt");ka(c$,function(){});m(c$,"init",function(d){this.e=d;this.vwr=this.e.vwr;return this},"~O");m(c$,"evaluate",function(d,a,b,c){switch(c){case 134218760:return 1<=b.length&&4==b[0].tok?d.addXStr((1==b.length?(new java.util.Date).toString():this.vwr.apiPlatform.getDateFormat(JS.SV.sValue(b[1])))+"\t"+JS.SV.sValue(b[0]).trim()):d.addXInt(System.currentTimeMillis()-JS.MathExt.t0-(0==b.length?0:b[0].asInt()));
 case 134218250:return 1==b.length&&2==b[0].tok?d.addXInt(b[0].intValue):d.addXFloat(Math.abs(b[0].asFloat()));case 134218242:case 134218245:case 134218244:case 134218246:return 1==b.length&&this.evaluateMath(d,b,c);case 1275069441:case 1275068928:case 1275068929:case 1275068930:case 1275068931:case 1275335685:case 1275334681:return this.evaluateList(d,a.intValue,b);case 268435520:0==b.length&&(d.wasX=!1);case 1275068418:return this.evaluateArray(d,b,1275068418==c&&268435665==a.tok);case 134217765:return d.addXObj(this.vwr.sm.getParameter(0==
 b.length?-2147483648:b[0].intValue));case 134217731:case 134221850:return this.evaluateQuaternion(d,b,c);case 1275068420:return this.evaluateBin(d,b);case 134221829:return this.evaluateCache(d,b);case 1275068934:case 1275068935:return this.evaluateRowCol(d,b,c);case 1765808134:return this.evaluateColor(d,b);case 134221831:return this.evaluateCompare(d,b);case 1228931587:case 134217736:case 1275203608:return this.evaluateConnected(d,b,c,a.intValue);case 1814695966:return this.evaluateUnitCell(d,b,
@@ -63,8 +63,8 @@ if(2==e&&(7==j||6==j||14==j))return d.addXObj(this.vwr.extractProperty(a[0].valu
 q=0;for(m=g.size();q<m;q++)if(k=g.get(q),6==k.tok){u=k.getMap();a="";for(p=0;p<e;p++)l=u.get(n[p]),a+=(0==p?"":j)+JS.SV.sValue(l);u=c.get(a);null==u&&c.put(a,u=JS.SV.newV(7,new JU.Lst));u.getList().addLast(k)}return d.addXMap(c)}if(null!=l){e=p.getList();a=new JU.Lst;for(q=l.nextSetBit(0);0<=q;q=l.nextSetBit(q+1))a.addLast(e.get(q));return d.addXList(a)}default:if(1275068725==b&&6==p.tok){c=new java.util.Hashtable;for(e=p.getMap().entrySet().iterator();e.hasNext()&&((q=e.next())||1);)a=q.getKey(),
 k=q.getValue().asString(),g=c.get(k),null==g&&c.put(k,g=new JU.Lst),g.addLast(a);if("count".equals(n))for(e=c.entrySet().iterator();e.hasNext()&&((q=e.next())||1);)q.setValue(Integer.$valueOf(q.getValue().size()));return d.addXMap(c)}f&&(j="[SELECT "+j+"]");return d.addXObj(this.vwr.extractProperty(p,j,-1))}!n.startsWith("bondinfo")&&(!n.startsWith("atominfo")&&!n.startsWith("modelkitinfo"))&&(j="atomInfo."+j)}q="";if(j.equalsIgnoreCase("fileContents")&&2<=e){k=JS.SV.sValue(a[1]);for(q=2;q<e;q++)k+=
 "|"+JS.SV.sValue(a[q]);q=k;k=e}else if(e>k)switch(a[k].tok){case 10:q=a[k++].value;j.equalsIgnoreCase("bondInfo")&&(e>k&&10==a[k].tok)&&(q=x(-1,[q,a[k].value]));break;case 6:case 4:this.vwr.checkPropertyParameter(j)&&(q=a[k++].value)}if(c&&(q=p.value,0>q.nextSetBit(0)))return d.addXStr("");g&&!c&&(j="auxiliaryInfo.models."+j);j=JU.PT.rep(j,".[","[");q=this.vwr.getProperty(null,j,q);k<e&&(q=this.vwr.extractProperty(q,a,k));return d.addXObj(m?JS.SV.safeJSON("value",q):JS.SV.isVariableType(q)?q:JU.Escape.toReadable(j,
-q))},"JS.ScriptMathProcessor,~A,~N,~B");m(c$,"evaluateFormat",function(d,a,b,c){var e=2>b.length||1287653388==a?d.getX():null,f=0==b.length?"%U":7==b[0].tok?null:JS.SV.sValue(b[0]);if(!c&&0<b.length&&null!=e&&10!=e.tok&&null!=f){if(2==b.length){var e=e.getList(),h=b[1].getList();if(null==e||null==h)return!1;e=JS.SV.getVariableList(this.getSublist(e,h))}b=x(-1,[b[0],e]);e=null}if(null==e){a=c?-1:JS.SV.getFormatType(f);if(0<=a&&2!=b.length)return!1;if(0<=a||2>b.length||7!=b[1].tok)return b=JS.SV.format(b,
-a),f.equalsIgnoreCase("json")?d.addXStr(b):d.addXObj(b);f=b[1].getList();b=x(-1,[b[0],null]);c=Array(f.size());for(e=c.length;0<=--e;)b[1]=f.get(e),c[e]=JS.SV.format(b,a).toString();return d.addXAS(c)}if(7==e.tok&&null==f)return e=e.getList(),h=b[0].getList(),f=this.getSublist(e,h),d.addXList(f);b=10==e.tok?e.value:null;a=JS.T.tokAttr(a,480);return d.addXObj(null==f?"":null==b?JS.SV.sprintf(JU.PT.formatCheck(f),e):this.e.getCmdExt().getBitsetIdent(b,f,e.value,!0,e.index,a))},"JS.ScriptMathProcessor,~N,~A,~B");
+q))},"JS.ScriptMathProcessor,~A,~N,~B");m(c$,"evaluateFormat",function(d,a,b,c){var e=2>b.length||1287653388==a?d.getX():null,f=0==b.length?"%U":7==b[0].tok?null:JS.SV.sValue(b[0]);if(!c&&0<b.length&&null!=e&&10!=e.tok&&null!=f){if(2==b.length){var e=e.getList(),h=b[1].getList();if(null==e||null==h)return!1;e=JS.SV.getVariableList(this.getSublist(e,h))}b=x(-1,[b[0],e]);e=null}if(null==e){if(null==f)return!1;a=c?-1:JS.SV.getFormatType(f);if(0<=a&&2!=b.length)return!1;if(0<=a||2>b.length||7!=b[1].tok)return b=
+JS.SV.format(b,a),f.equalsIgnoreCase("json")?d.addXStr(b):d.addXObj(b);f=b[1].getList();b=x(-1,[b[0],null]);c=Array(f.size());for(e=c.length;0<=--e;)b[1]=f.get(e),c[e]=JS.SV.format(b,a).toString();return d.addXAS(c)}if(7==e.tok&&null==f)return e=e.getList(),h=b[0].getList(),f=this.getSublist(e,h),d.addXList(f);b=10==e.tok?e.value:null;a=JS.T.tokAttr(a,480);return d.addXObj(null==f?"":null==b?JS.SV.sprintf(JU.PT.formatCheck(f),e):this.e.getCmdExt().getBitsetIdent(b,f,e.value,!0,e.index,a))},"JS.ScriptMathProcessor,~N,~A,~B");
 m(c$,"getSublist",function(d,a){for(var b=new JU.Lst,c,e,f,h=0,g=d.size();h<g;h++)switch(e=d.get(h),e.tok){case 6:c=e.getMap();f=new JU.Lst;for(var k=0,j=a.size();k<j;k++)e=c.get(JS.SV.sValue(a.get(k))),f.addLast(null==e?JS.SV.newS(""):e);b.addLast(JS.SV.getVariableList(f));break;case 7:c=new java.util.Hashtable;f=e.getList();k=0;for(j=Math.min(f.size(),a.size());k<j;k++)c.put(JS.SV.sValue(a.get(k)),f.get(k));b.addLast(JS.SV.getVariable(c))}return b},"JU.Lst,JU.Lst");m(c$,"evaluateList",function(d,
 a,b){var c=b.length,e=d.getX(),f=7==e.tok,h;switch(a){case 1275335685:return 2==c&&d.addX(e.pushPop(b[0],b[1]))||1==c&&d.addX(e.pushPop(null,b[0]));case 1275334681:return 1==c&&d.addX(e.pushPop(b[0],null))||0==c&&d.addX(e.pushPop(null,null));case 1275069441:if(1!=c&&2!=c)return!1;break;case 1275069447:case 1275069446:break;default:if(1!=c)return!1}var g=null,k=null,j=null;if(2==c){var l=JS.SV.sValue(b[0]);h=b[1];if(1275069441==a){g=f?JS.SV.strListValue(e):JU.PT.split(JS.SV.sValue(e),"\n");k=7==h.tok?
 JS.SV.strListValue(h):JU.PT.split(JS.SV.sValue(h),"\n");j=Array(c=Math.max(g.length,k.length));for(e=0;e<c;e++)j[e]=(e>=g.length?"":g[e])+l+(e>=k.length?"":k[e]);return d.addXAS(j)}if(1073742335!=h.tok)return!1;j=e.getList();(c=0==l.length)&&(l=",");if(1275069446==a){k=Array(j.size());for(e=j.size();0<=--e;)if(b=j.get(e).getList(),null==b)k[e]=j.get(e);else{a=new JU.SB;f=0;for(g=b.size();f<g;f++)0<f&&a.append(l),h=b.get(f),a.append(c&&4==h.tok?'"'+JU.PT.rep(h.value,'"','""')+'"':""+h.asString());
@@ -73,7 +73,7 @@ b.indexOf("."))try{n.addLast(JS.SV.newI(Integer.parseInt(b)));continue}catch(m){
 l=e.getList(),t=h.getList();f?c=l.size():u?c=2147483647:(g=JU.PT.split(JS.SV.sValue(e),"\n"),n=C(c=g.length,0),JU.PT.parseFloatArrayData(g,n));if(j&&1275069446!=a){j=0;if(f)for(e=c;0<=--e;)j+=JS.SV.fValue(l.get(e));else if(!u)for(e=c;0<=--e;)j+=n[e];return d.addXFloat(j)}if(1275069446==a&&4==h.tok){a=new JU.SB;if(u)a.append(JS.SV.sValue(e));else{b=j?"":h.value.toString();for(e=0;e<c;e++)a.append(0<e?b:"").append(JS.SV.sValue(l.get(e)))}return d.addXStr(a.toString())}var x=null;q?x=h:7==h.tok?c=Math.min(c,
 t.size()):(k=JU.PT.split(JS.SV.sValue(h),"\n"),y=C(k.length,0),JU.PT.parseFloatArrayData(k,y),c=Math.min(c,y.length));var V=this.opTokenFor(a);if(f&&j)return j=new JU.Lst,d.addXList(this.addAllLists(e.getList(),j));b=u?e:null;var A,B=2147483647==c;B&&(c=1);for(var D=Array(c),e=0;e<c;e++){A=q?x:7==h.tok?t.get(e):Float.isNaN(y[e])?JS.SV.getVariable(JS.SV.unescapePointOrBitsetAsVariable(k[e])):JS.SV.newF(y[e]);u||(b=f?l.get(e):Float.isNaN(n[e])?JS.SV.getVariable(JS.SV.unescapePointOrBitsetAsVariable(g[e])):
 JS.SV.newF(n[e]));1275069446==a&&7!=b.tok&&(j=new JU.Lst,j.addLast(b),b=JS.SV.getVariableList(j));if(!d.binaryOp(V,b,A))return!1;D[e]=d.getX()}return B?d.addXObj(D[0]):d.addXAV(D)},"JS.ScriptMathProcessor,~N,~A");m(c$,"addAllLists",function(d,a){for(var b=d.size(),c=0;c<b;c++){var e=d.get(c);7==e.tok?this.addAllLists(e.getList(),a):a.addLast(e)}return a},"JU.Lst,JU.Lst");m(c$,"evaluateLoad",function(d,a,b){if(1>a.length||3<a.length)return!1;var c=JV.FileManager.fixDOSName(JS.SV.sValue(a[0])),e=1<
-a.length&&1073742335==a[1].tok,f=this.vwr.async||2<a.length&&1073742335==a[a.length-1].tok,h=1<a.length&&2==a[1].tok?a[1].asInt():-1;a=1<a.length&&a[1].asString().equalsIgnoreCase("JSON");if(e)return d.addXMap(this.vwr.fm.getFileAsMap(c,null));e=c.startsWith("?");if(JV.Viewer.isJS&&(e||f)){if(b&&e)return d.addXStr("");c=this.e.loadFileAsync("load()_",c,d.oPt,!0)}b=b?this.vwr.fm.getFilePath(c,!1,!1):this.vwr.getFileAsString4(c,h,!1,!1,!0,"script");try{return a?d.addXObj(this.vwr.parseJSON(b)):d.addXStr(b)}catch(g){if(L(g,
+a.length&&1073742335==a[1].tok,f=this.vwr.async||2<a.length&&1073742335==a[a.length-1].tok,h=1<a.length&&2==a[1].tok?a[1].asInt():-1;a=1<a.length&&a[1].asString().equalsIgnoreCase("JSON");if(e)return d.addXMap(this.vwr.fm.getFileAsMap(c,null,!1));e=c.startsWith("?");if(JV.Viewer.isJS&&(e||f)){if(b&&e)return d.addXStr("");c=this.e.loadFileAsync("load()_",c,d.oPt,!0)}b=b?this.vwr.fm.getFilePath(c,!1,!1):this.vwr.getFileAsString4(c,h,!1,!1,!0,"script");try{return a?d.addXObj(this.vwr.parseJSON(b)):d.addXStr(b)}catch(g){if(L(g,
 Exception))return!1;throw g;}},"JS.ScriptMathProcessor,~A,~B");m(c$,"evaluateMath",function(d,a,b){a=JS.SV.fValue(a[0]);switch(b){case 134218246:a=Math.sqrt(a);break;case 134218244:a=Math.sin(3.141592653589793*a/180);break;case 134218245:a=Math.cos(3.141592653589793*a/180);break;case 134218242:a=180*Math.acos(a)/3.141592653589793}return d.addXFloat(a)},"JS.ScriptMathProcessor,~A,~N");m(c$,"evaluateMeasure",function(d,a,b){var c=0;switch(b){case 1745489939:b=null;for(var e=new JU.Lst,f=C(-1,[3.4028235E38,
 3.4028235E38]),h=null,g=null,k=!1,j=!1,l=0,u=!1,n=null,m=0,p=3.4028235E38,q=!1,y=!1,n=0;n<a.length;n++)switch(a[n].tok){case 10:var t=a[n].value;0==t.length()&&(u=!0);e.addLast(t);c++;m++;break;case 8:t=new JU.Point3fi;t.setT(a[n].value);e.addLast(t);c++;break;case 2:case 3:f[l++%2]=JS.SV.fValue(a[n]);break;case 4:t=JS.SV.sValue(a[n]);if(t.startsWith("property_")){b=t;break}t.equalsIgnoreCase("vdw")||t.equalsIgnoreCase("vanderwaals")?p=(n+1<a.length&&2==a[n+1].tok?a[++n].asInt():100)/100:t.equalsIgnoreCase("notConnected")?
 j=!0:t.equalsIgnoreCase("connected")?k=!0:t.equalsIgnoreCase("minArray")?q=1<=m:t.equalsIgnoreCase("asArray")||0==t.length?y=1<=m:JM.Measurement.isUnits(t)?g=t.toLowerCase():h=c+":"+t;break;default:return!1}if(2>c||4<c||2<l||j&&k)return!1;if(u||3.4028235E38!=p&&(2!=m||2!=c))return d.addXStr("");n=3.4028235E38==p?new J.atomdata.RadiusData(f,0,null,null):new J.atomdata.RadiusData(null,p,J.atomdata.RadiusData.EnumType.FACTOR,J.c.VDW.AUTO);a=this.vwr.newMeasurementData(null,e).set(0,null,n,b,h,g,null,
@@ -118,18 +118,18 @@ JS.SV.sValue(a[1])));case 1094713349:case 1094713350:return d.addXBs(this.vwr.ms
 case 1086324744:g=JS.SV.sValue(a[2]);break;default:return!1}}var q=null,h=c=null,x=a.length-1;switch(a[x].tok){case 9:q=a[x].value;break;case 8:c=a[x].value;JS.SV.sValue(a[1]).equalsIgnoreCase("hkl")&&(q=this.e.getHklPlane(c,NaN,null));break;case 7:h=2==x&&7==a[1].tok?a[1].getList():null,c=2==x?JS.SV.ptValue(a[1]):1==x?JU.P3.new3(NaN,0,0):null}if(null!=q)return d.addXBs(k.getAtomsNearPlane(f,q));k=10==a[x].tok?a[x].value:null;null==e&&(e=k);if(0<x&&null==c&&null==h&&null==e)return!1;if(1814695966==
 p)return(null!=e||null!=c)&&d.addXObj(this.vwr.ms.getUnitCellPointsWithin(f,e,c,l));if(null!=c||null!=h){if(7==a[x].tok){b=a[x].getList();p=Array(b.size());for(a=p.length;0<=--a;)p[a]=JS.SV.ptValue(b.get(a));b=null;if(null!=h){b=Array(h.size());for(a=b.length;0<=--a;)b[a]=JS.SV.ptValue(h.get(a))}a=Array(1);null!=e&&(e.and(this.vwr.getAllAtoms()),b=this.vwr.ms.at);switch(J.bspt.PointIterator.withinDistPoints(f,c,p,b,e,a)){case 10:return d.addXBs(a[0]);case 134217751:return d.addXPt(a[0]);case 1073742001:return d.addXList(a[0]);
 case 1275068418:return d.addXAI(a[0]);case 4:return d.addXStr(a[0]);default:return!1}}return d.addXBs(this.vwr.getAtomsNearPt(f,c,null))}if(1086324744==p)return d.addXBs(this.vwr.ms.getSequenceBits(g,e,new JU.BS));null==e&&(e=new JU.BS);if(!n)try{return d.addXBs(this.vwr.ms.getAtoms(p,e))}catch(t){if(L(t,Exception))return!1;throw t;}if(m)return d.addXBs(this.vwr.getGroupsWithin($(f),e));j&&(s=new J.atomdata.RadiusData(null,10<f?f/100:f,10<f?J.atomdata.RadiusData.EnumType.FACTOR:J.atomdata.RadiusData.EnumType.OFFSET,
-J.c.VDW.AUTO),0>f&&(f=0));e=this.vwr.ms.getAtomsWithinRadius(f,b?k:e,l,s,b?e:null);b&&e.andNot(k);return d.addXBs(e)},"JS.ScriptMathProcessor,~A,~B");m(c$,"evaluateWrite",function(d,a){switch(a.length){case 0:return!1;case 1:var b=a[0].asString().toUpperCase();if(b.equals("PNGJ"))return d.addXMap(this.vwr.fm.getFileAsMap(null,"PNGJ"));if(JU.PT.isOneOf(b,";ZIP;ZIPALL;JMOL;")){var c=new java.util.Hashtable,e=new JU.OC;c.put("outputChannel",e);this.vwr.createZip(null,b,c);b=JU.Rdr.getBIS(e.toByteArray());
-c=new java.util.Hashtable;this.vwr.readFileAsMap(b,c,null);return d.addXMap(c)}}return d.addXStr(this.e.getCmdExt().dispatch(134221856,!0,a))},"JS.ScriptMathProcessor,~A");m(c$,"getAtomsNearSurface",function(d,a){var b=x(-1,[a,null,null]);if(this.e.getShapePropertyData(24,"getVertices",b))return this.getAtomsNearPts(d,b[1],b[2]);b[1]=Integer.$valueOf(0);b[2]=Integer.$valueOf(-1);if(this.e.getShapePropertyData(22,"getCenter",b))return this.vwr.getAtomsNearPt(d,b[2],null);b[1]=Float.$valueOf(d);return this.e.getShapePropertyData(21,
-"getAtomsWithin",b)?b[2]:new JU.BS},"~N,~S");m(c$,"getAtomsNearPts",function(d,a,b){var c=new JU.BS;if(0==a.length||null!=b&&b.isEmpty())return c;null==b&&(b=JU.BSUtil.setAll(a.length));for(var e=this.vwr.ms.at,f=this.vwr.ms.ac;0<=--f;){var h=e[f];if(null!=h)for(var g=b.nextSetBit(0);0<=g;g=b.nextSetBit(g+1))if(h.distance(a[g])<d){c.set(f);break}}return c},"~N,~A,JU.BS");m(c$,"getMinMax",function(d,a,b){for(var c=null,e=null,f=0,h=null;;){if(JU.AU.isAF(d)){if(1275068725==a)return NaN;c=d;f=c.length;
-if(0==f)break}else if(y(d,JU.Lst))if(e=d,f=e.size(),0==f){if(1275068725!=a)break}else{if(1275068725!=a){d=e.get(0);if(8==d.tok)return this.getMinMaxPoint(e,a);if(4==d.tok&&d.value.startsWith("{")){b=JS.SV.ptValue(d);if(y(b,JU.P3))return this.getMinMaxPoint(e,a);if(y(b,JU.P4))return this.getMinMaxQuaternion(e,a);break}}}else break;var g,k=!1;switch(a){case 1275068725:h=new java.util.Hashtable;d=g=0;break;case 32:k=!0;d=3.4028235E38;g=2147483647;break;case 64:d=-3.4028235E38;g=-2147483647;break;default:d=
-g=0}for(var j=0,l=0,m=!0,n=1275068725==a;0<=--f;){var s=null==e?null:e.get(f),p=!b?null:null==s?JS.SV.vF:s,q=n?1:null==c?JS.SV.fValue(p):c[f];if(!Float.isNaN(q))switch(l++,a){case 160:case 192:j+=q*q;case 128:case 96:d+=q;break;case 1275068725:s=null==p?s.toString():p.asString();p=h.get(s);h.put(s,null==p?new Integer(1):new Integer(p.intValue()+1));break;case 32:case 64:m=(new Boolean(m&2==p.tok)).valueOf(),k==q<d&&(d=q,m&&(g=p.intValue))}}if(1275068725==a)return h;if(0==l)break;switch(a){case 96:d/=
-l;break;case 192:if(1==l)break;d=Math.sqrt((j-d*d/l)/(l-1));break;case 32:case 64:if(m)return Integer.$valueOf(g);break;case 160:d=j}return Float.$valueOf(d)}return JS.MathExt.nan},"~O,~N,~B");m(c$,"getMinMaxPoint",function(d,a){var b=null,c=null,e=0;y(d,Array)?(b=d,e=b.length):y(d,JU.Lst)&&(c=d,e=c.size());if(null==c&&null==b)return JS.MathExt.nan;for(var f=new JU.P3,h=C(e,0),g=0;3>g;g++){for(var k=0;k<e;k++){var j=null==b?JS.SV.ptValue(c.get(k)):b[k];if(null==j)return JS.MathExt.nan;switch(g){case 0:h[k]=
-j.x;break;case 1:h[k]=j.y;break;case 2:h[k]=j.z}}k=this.getMinMax(h,a,!0);if(!y(k,Number))return JS.MathExt.nan;k=k.floatValue();switch(g){case 0:f.x=k;break;case 1:f.y=k;break;case 2:f.z=k}}return f},"~O,~N");m(c$,"getMinMaxQuaternion",function(d,a){var b;switch(a){case 32:case 64:case 128:case 160:return JS.MathExt.nan}for(;;){b=this.e.getQuaternionArray(d,1073742001);if(null==b)break;var c=C(1,0);b=JU.Quat.sphereMean(b,c,1E-4);switch(a){case 96:return b;case 192:return Float.$valueOf(c[0])}break}return JS.MathExt.nan},
-"JU.Lst,~N");m(c$,"getPatternMatcher",function(){return null==this.pm?this.pm=J.api.Interface.getUtil("PatternMatcher",this.e.vwr,"script"):this.pm});m(c$,"opTokenFor",function(d){switch(d){case 1275069441:case 1275069446:return JS.T.tokenPlus;case 1275068931:return JS.T.tokenMinus;case 1275068929:return JS.T.tokenTimes;case 1275068930:return JS.T.tokenMul3;case 1275068928:return JS.T.tokenDivide}return null},"~N");m(c$,"setContactBitSets",function(d,a,b,c,e,f){var h,g;null==a?(a=JU.BSUtil.setAll(this.vwr.ms.ac),
-JU.BSUtil.andNot(a,this.vwr.slm.bsDeleted),a.andNot(d),h=!1):(g=JU.BSUtil.copy(d),g.or(a),g=this.vwr.ms.getModelBS(g,!1).cardinality(),h=1<g,f&&(1<g&&!this.e.tQuiet)&&this.e.showString(J.i18n.GT.$("Note: More than one model is involved in this contact!")));if(!d.equals(a)){if(f=!b||d.cardinality()<a.cardinality())g=this.vwr.ms.getAtomsWithinRadius(c,d,h,Float.isNaN(c)?e:null,null),a.and(g);b&&(g=this.vwr.ms.getAtomsWithinRadius(c,a,h,Float.isNaN(c)?e:null,null),d.and(g),f||(g=this.vwr.ms.getAtomsWithinRadius(c,
-d,h,Float.isNaN(c)?e:null,null),a.and(g)),g=JU.BSUtil.copy(a),g.and(d),g.equals(d)?a.andNot(d):g.equals(a)&&d.andNot(a))}return a},"JU.BS,JU.BS,~B,~N,J.atomdata.RadiusData,~B");c$.nan=c$.prototype.nan=Float.$valueOf(NaN);c$.t0=c$.prototype.t0=System.currentTimeMillis()});Y("J.bspt");Z(null,"J.bspt.PointIterator","java.lang.Float JU.BS $.Lst $.P3 J.bspt.Bspt JU.BSUtil $.Point3fi".split(" "),function(){c$=la(J.bspt,"PointIterator");c$.withinDistPoints=m(c$,"withinDistPoints",function(d,a,b,c,e,f){var h=
-new JU.Lst,g=new J.bspt.Bspt(3,0),k;if(null!=a&&Float.isNaN(a.x)){for(var j=Array(b.length),l=j.length;0<=--l;){k=b[l];if(null==k)return 0;null==e?(a=new JU.Point3fi,a.setT(k),a.i=l,j[l]=a,g.addTuple(a)):g.addTuple(k)}k=g.allocateCubeIterator();if(null!=e){b=JU.BS.newN(c.length);for(l=e.nextSetBit(0);0<=l;l=e.nextSetBit(l+1)){k.initialize(c[l],d,!1);for(g=d*d;k.hasMoreElements();)if(k.nextElement().distanceSquared(c[l])<=g){b.set(l);break}}f[0]=b;return 10}b=JU.BSUtil.newBitSet2(0,b.length);for(l=
-j.length;0<=--l;){k.initialize(a=j[l],d,!1);g=d*d;for(e=0;k.hasMoreElements();)c=k.nextElement(),b.get(c.i)&&(c.distanceSquared(a)<=g&&1<++e)&&b.clear(c.i)}for(l=b.nextSetBit(0);0<=l;l=b.nextSetBit(l+1))h.addLast(JU.P3.newP(j[l]));f[0]=h;return 1073742001}if(0==d){if(null==c){g=3.4028235E38;j=null;for(l=b.length;0<=--l;)h=b[l],d=h.distanceSquared(a),d<g&&(j=h,g=d);f[0]=null==j?"":j;return null==j?4:134217751}j=O(c.length,0);for(l=j.length;0<=--l;){g=3.4028235E38;e=-1;a=c[l];for(k=b.length;0<=--k;)h=
-b[k],d=h.distanceSquared(a),d<g&&(e=k,g=d);j[l]=e}f[0]=j;return 1275068418}for(l=b.length;0<=--l;)g.addTuple(b[l]);k=g.allocateCubeIterator();k.initialize(a,d,!1);for(g=d*d;k.hasMoreElements();)c=k.nextElement(),c.distanceSquared(a)<=g&&h.addLast(c);k.release();f[0]=h;return 1073742001},"~N,JU.P3,~A,~A,JU.BS,~A")})})(Clazz,Clazz.getClassName,Clazz.newLongArray,Clazz.doubleToByte,Clazz.doubleToInt,Clazz.doubleToLong,Clazz.declarePackage,Clazz.instanceOf,Clazz.load,Clazz.instantialize,Clazz.decorateAsClass,
-Clazz.floatToInt,Clazz.floatToLong,Clazz.makeConstructor,Clazz.defineEnumConstant,Clazz.exceptionOf,Clazz.newIntArray,Clazz.defineStatics,Clazz.newFloatArray,Clazz.declareType,Clazz.prepareFields,Clazz.superConstructor,Clazz.newByteArray,Clazz.declareInterface,Clazz.p0p,Clazz.pu$h,Clazz.newShortArray,Clazz.innerTypeInstance,Clazz.isClassDefined,Clazz.prepareCallback,Clazz.newArray,Clazz.castNullAs,Clazz.floatToShort,Clazz.superCall,Clazz.decorateAsType,Clazz.newBooleanArray,Clazz.newCharArray,Clazz.implementOf,
-Clazz.newDoubleArray,Clazz.overrideConstructor,Clazz.clone,Clazz.doubleToShort,Clazz.getInheritedLevel,Clazz.getParamsType,Clazz.isAF,Clazz.isAB,Clazz.isAI,Clazz.isAS,Clazz.isASS,Clazz.isAP,Clazz.isAFloat,Clazz.isAII,Clazz.isAFF,Clazz.isAFFF,Clazz.tryToSearchAndExecute,Clazz.getStackTrace,Clazz.inheritArgs,Clazz.alert,Clazz.defineMethod,Clazz.overrideMethod,Clazz.declareAnonymous,Clazz.cloneFinals);
+J.c.VDW.AUTO),0>f&&(f=0));e=this.vwr.ms.getAtomsWithinRadius(f,b?k:e,l,s,b?e:null);b&&e.andNot(k);return d.addXBs(e)},"JS.ScriptMathProcessor,~A,~B");m(c$,"evaluateWrite",function(d,a){var b=a.length,c=!1;2==b&&1073742335==a[1].tok&&(b=1,c=!0);switch(b){case 0:return!1;case 1:var e=a[0].asString().toUpperCase();if(e.equals("PNGJ"))return b=this.vwr.fm.getFileAsMap(null,"PNGJ",c),c?d.addX(JS.SV.newV(15,new JU.BArray(b))):d.addXMap(b);if(JU.PT.isOneOf(e,";ZIP;ZIPALL;JMOL;")){var b=new java.util.Hashtable,
+f=new JU.OC;b.put("outputChannel",f);this.vwr.createZip(null,e,b);e=f.toByteArray();if(c)return d.addX(JS.SV.newV(15,new JU.BArray(e)));b=new java.util.Hashtable;this.vwr.readFileAsMap(JU.Rdr.getBIS(e),b,null);return d.addXMap(b)}}return d.addXStr(this.e.getCmdExt().dispatch(134221856,!0,a))},"JS.ScriptMathProcessor,~A");m(c$,"getAtomsNearSurface",function(d,a){var b=x(-1,[a,null,null]);if(this.e.getShapePropertyData(24,"getVertices",b))return this.getAtomsNearPts(d,b[1],b[2]);b[1]=Integer.$valueOf(0);
+b[2]=Integer.$valueOf(-1);if(this.e.getShapePropertyData(22,"getCenter",b))return this.vwr.getAtomsNearPt(d,b[2],null);b[1]=Float.$valueOf(d);return this.e.getShapePropertyData(21,"getAtomsWithin",b)?b[2]:new JU.BS},"~N,~S");m(c$,"getAtomsNearPts",function(d,a,b){var c=new JU.BS;if(0==a.length||null!=b&&b.isEmpty())return c;null==b&&(b=JU.BSUtil.setAll(a.length));for(var e=this.vwr.ms.at,f=this.vwr.ms.ac;0<=--f;){var h=e[f];if(null!=h)for(var g=b.nextSetBit(0);0<=g;g=b.nextSetBit(g+1))if(h.distance(a[g])<
+d){c.set(f);break}}return c},"~N,~A,JU.BS");m(c$,"getMinMax",function(d,a,b){for(var c=null,e=null,f=0,h=null;;){if(JU.AU.isAF(d)){if(1275068725==a)return NaN;c=d;f=c.length;if(0==f)break}else if(y(d,JU.Lst))if(e=d,f=e.size(),0==f){if(1275068725!=a)break}else{if(1275068725!=a){d=e.get(0);if(8==d.tok)return this.getMinMaxPoint(e,a);if(4==d.tok&&d.value.startsWith("{")){b=JS.SV.ptValue(d);if(y(b,JU.P3))return this.getMinMaxPoint(e,a);if(y(b,JU.P4))return this.getMinMaxQuaternion(e,a);break}}}else break;
+var g,k=!1;switch(a){case 1275068725:h=new java.util.Hashtable;d=g=0;break;case 32:k=!0;d=3.4028235E38;g=2147483647;break;case 64:d=-3.4028235E38;g=-2147483647;break;default:d=g=0}for(var j=0,l=0,m=!0,n=1275068725==a;0<=--f;){var s=null==e?null:e.get(f),p=!b?null:null==s?JS.SV.vF:s,q=n?1:null==c?JS.SV.fValue(p):c[f];if(!Float.isNaN(q))switch(l++,a){case 160:case 192:j+=q*q;case 128:case 96:d+=q;break;case 1275068725:s=null==p?s.toString():p.asString();p=h.get(s);h.put(s,null==p?new Integer(1):new Integer(p.intValue()+
+1));break;case 32:case 64:m=(new Boolean(m&2==p.tok)).valueOf(),k==q<d&&(d=q,m&&(g=p.intValue))}}if(1275068725==a)return h;if(0==l)break;switch(a){case 96:d/=l;break;case 192:if(1==l)break;d=Math.sqrt((j-d*d/l)/(l-1));break;case 32:case 64:if(m)return Integer.$valueOf(g);break;case 160:d=j}return Float.$valueOf(d)}return JS.MathExt.nan},"~O,~N,~B");m(c$,"getMinMaxPoint",function(d,a){var b=null,c=null,e=0;y(d,Array)?(b=d,e=b.length):y(d,JU.Lst)&&(c=d,e=c.size());if(null==c&&null==b)return JS.MathExt.nan;
+for(var f=new JU.P3,h=C(e,0),g=0;3>g;g++){for(var k=0;k<e;k++){var j=null==b?JS.SV.ptValue(c.get(k)):b[k];if(null==j)return JS.MathExt.nan;switch(g){case 0:h[k]=j.x;break;case 1:h[k]=j.y;break;case 2:h[k]=j.z}}k=this.getMinMax(h,a,!0);if(!y(k,Number))return JS.MathExt.nan;k=k.floatValue();switch(g){case 0:f.x=k;break;case 1:f.y=k;break;case 2:f.z=k}}return f},"~O,~N");m(c$,"getMinMaxQuaternion",function(d,a){var b;switch(a){case 32:case 64:case 128:case 160:return JS.MathExt.nan}for(;;){b=this.e.getQuaternionArray(d,
+1073742001);if(null==b)break;var c=C(1,0);b=JU.Quat.sphereMean(b,c,1E-4);switch(a){case 96:return b;case 192:return Float.$valueOf(c[0])}break}return JS.MathExt.nan},"JU.Lst,~N");m(c$,"getPatternMatcher",function(){return null==this.pm?this.pm=J.api.Interface.getUtil("PatternMatcher",this.e.vwr,"script"):this.pm});m(c$,"opTokenFor",function(d){switch(d){case 1275069441:case 1275069446:return JS.T.tokenPlus;case 1275068931:return JS.T.tokenMinus;case 1275068929:return JS.T.tokenTimes;case 1275068930:return JS.T.tokenMul3;
+case 1275068928:return JS.T.tokenDivide}return null},"~N");m(c$,"setContactBitSets",function(d,a,b,c,e,f){var h,g;null==a?(a=JU.BSUtil.setAll(this.vwr.ms.ac),JU.BSUtil.andNot(a,this.vwr.slm.bsDeleted),a.andNot(d),h=!1):(g=JU.BSUtil.copy(d),g.or(a),g=this.vwr.ms.getModelBS(g,!1).cardinality(),h=1<g,f&&(1<g&&!this.e.tQuiet)&&this.e.showString(J.i18n.GT.$("Note: More than one model is involved in this contact!")));if(!d.equals(a)){if(f=!b||d.cardinality()<a.cardinality())g=this.vwr.ms.getAtomsWithinRadius(c,
+d,h,Float.isNaN(c)?e:null,null),a.and(g);b&&(g=this.vwr.ms.getAtomsWithinRadius(c,a,h,Float.isNaN(c)?e:null,null),d.and(g),f||(g=this.vwr.ms.getAtomsWithinRadius(c,d,h,Float.isNaN(c)?e:null,null),a.and(g)),g=JU.BSUtil.copy(a),g.and(d),g.equals(d)?a.andNot(d):g.equals(a)&&d.andNot(a))}return a},"JU.BS,JU.BS,~B,~N,J.atomdata.RadiusData,~B");c$.nan=c$.prototype.nan=Float.$valueOf(NaN);c$.t0=c$.prototype.t0=System.currentTimeMillis()});Y("J.bspt");Z(null,"J.bspt.PointIterator","java.lang.Float JU.BS $.Lst $.P3 J.bspt.Bspt JU.BSUtil $.Point3fi".split(" "),
+function(){c$=la(J.bspt,"PointIterator");c$.withinDistPoints=m(c$,"withinDistPoints",function(d,a,b,c,e,f){var h=new JU.Lst,g=new J.bspt.Bspt(3,0),k;if(null!=a&&Float.isNaN(a.x)){for(var j=Array(b.length),l=j.length;0<=--l;){k=b[l];if(null==k)return 0;null==e?(a=new JU.Point3fi,a.setT(k),a.i=l,j[l]=a,g.addTuple(a)):g.addTuple(k)}k=g.allocateCubeIterator();if(null!=e){b=JU.BS.newN(c.length);for(l=e.nextSetBit(0);0<=l;l=e.nextSetBit(l+1)){k.initialize(c[l],d,!1);for(g=d*d;k.hasMoreElements();)if(k.nextElement().distanceSquared(c[l])<=
+g){b.set(l);break}}f[0]=b;return 10}b=JU.BSUtil.newBitSet2(0,b.length);for(l=j.length;0<=--l;){k.initialize(a=j[l],d,!1);g=d*d;for(e=0;k.hasMoreElements();)c=k.nextElement(),b.get(c.i)&&(c.distanceSquared(a)<=g&&1<++e)&&b.clear(c.i)}for(l=b.nextSetBit(0);0<=l;l=b.nextSetBit(l+1))h.addLast(JU.P3.newP(j[l]));f[0]=h;return 1073742001}if(0==d){if(null==c){g=3.4028235E38;j=null;for(l=b.length;0<=--l;)h=b[l],d=h.distanceSquared(a),d<g&&(j=h,g=d);f[0]=null==j?"":j;return null==j?4:134217751}j=O(c.length,
+0);for(l=j.length;0<=--l;){g=3.4028235E38;e=-1;a=c[l];for(k=b.length;0<=--k;)h=b[k],d=h.distanceSquared(a),d<g&&(e=k,g=d);j[l]=e}f[0]=j;return 1275068418}for(l=b.length;0<=--l;)g.addTuple(b[l]);k=g.allocateCubeIterator();k.initialize(a,d,!1);for(g=d*d;k.hasMoreElements();)c=k.nextElement(),c.distanceSquared(a)<=g&&h.addLast(c);k.release();f[0]=h;return 1073742001},"~N,JU.P3,~A,~A,JU.BS,~A")})})(Clazz,Clazz.getClassName,Clazz.newLongArray,Clazz.doubleToByte,Clazz.doubleToInt,Clazz.doubleToLong,Clazz.declarePackage,
+Clazz.instanceOf,Clazz.load,Clazz.instantialize,Clazz.decorateAsClass,Clazz.floatToInt,Clazz.floatToLong,Clazz.makeConstructor,Clazz.defineEnumConstant,Clazz.exceptionOf,Clazz.newIntArray,Clazz.defineStatics,Clazz.newFloatArray,Clazz.declareType,Clazz.prepareFields,Clazz.superConstructor,Clazz.newByteArray,Clazz.declareInterface,Clazz.p0p,Clazz.pu$h,Clazz.newShortArray,Clazz.innerTypeInstance,Clazz.isClassDefined,Clazz.prepareCallback,Clazz.newArray,Clazz.castNullAs,Clazz.floatToShort,Clazz.superCall,
+Clazz.decorateAsType,Clazz.newBooleanArray,Clazz.newCharArray,Clazz.implementOf,Clazz.newDoubleArray,Clazz.overrideConstructor,Clazz.clone,Clazz.doubleToShort,Clazz.getInheritedLevel,Clazz.getParamsType,Clazz.isAF,Clazz.isAB,Clazz.isAI,Clazz.isAS,Clazz.isASS,Clazz.isAP,Clazz.isAFloat,Clazz.isAII,Clazz.isAFF,Clazz.isAFFF,Clazz.tryToSearchAndExecute,Clazz.getStackTrace,Clazz.inheritArgs,Clazz.alert,Clazz.defineMethod,Clazz.overrideMethod,Clazz.declareAnonymous,Clazz.cloneFinals);
